@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from mvvmQt.Widget import Widget, Window
+from mvvmQt.rewriteContorls import Widget, Window, Label
 from PyQt5.QtWidgets import QFrame, QPushButton, QGridLayout, QLayout, QHBoxLayout, QVBoxLayout, QLabel, QTabWidget\
     , QStatusBar
 from mvvmQt.Observable import ObservableBase
@@ -207,7 +207,7 @@ class Element:
         self.qt = QPushButton(self.dom.text())
 
     def createLabel(self):
-        self.qt = QLabel(self.dom.text())
+        self.qt = Label(self.dom.text())
 
     def createTab(self):
         self.qt = QTabWidget()
